<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Michael Clay <claym@osuosl.org>                               |
// |          Frederic Wenzel <fred@osuosl.org>                             |
// |          Zack Bartel <bartel@osuosl.org>                               |
// +------------------------------------------------------------------------+
// $Id: WorkgroupDataList.php 4822 2006-09-15 18:57:40Z morgabra $

require_once("$phphtmllib/widgets/data_list/DefaultGUIDataList.inc");
require_once(DAOEXT.'/workgroup.php');
require_once(HTCLASS.'/DB_DataObjectDataListSource.php');

/**
 *  This class is the extension of DefaultGUIDataList made for use with the Workgroup 
 *  table.
 */
class WorkgroupDataList extends DefaultGUIDataList
{

//{{{   vars

    var $_default_rows_per_page = 38;

//}}}
//{{{   get_data_source()

    /**
     *  This method sets up the data source for the data list to be displayed.
     *  In Maintain's case, this means creating DBDataObject Data Source objects.
     */
    function get_data_source()
    {
        global $user;

        $workgroup = DB_DataObject::Factory('workgroup');

        /* If we are coming from the admin.php page and we are an admin then we
           see all workgroups in all zones */
        
        if (strcasecmp($_REQUEST['action'], 'show_admin') || !$user->is_admin())  {
        
            /* Only get workgroups in this zone */
            $zw = DB_DataObject::Factory('zone_workgroup');
            $zw->zone = $_SESSION['zone'];
            $workgroup->joinAdd($zw);
            /* zone_workgroup.id seems to "overwrite" workgroup.id */
            $workgroup->selectAdd();
            $workgroup->selectAdd('workgroup.id');
            $workgroup->selectAdd('workgroup.name');
        }
        $src = &new DB_DataObjectDataListSource($workgroup);
        $this->set_data_source($src);
        $this->_default_orderby = 'name';
    }

//}}}
//{{{   user_setup()

    /**
     *  This method sets up the table columns and various other attributes like
     *  which of those columns is sortable, searchable, etc...
     */
    function user_setup()
    {
        global $conf;
        
        $this->set_actionbar(true);
        $access = true;

        // number of rows per page
        //$this->set_numrows(5);

        $this->add_header_item(_("Name"), '20%', 'name', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Zone(s)"), '20%');
        $this->add_header_item(_("Action"),'20%');
        $this->search_disable();
    }

//}}}
//{{{   build_column_item()

    /**
     *  This method takes care of how the data in the columns will appear.
     *
     *  @param  array   $row_data   the row in question
     *  @param  string  $col_name   the column in question
     *
     *  @return Object  $obj        the custom rendering of the data
     */
    function build_column_item($row_data, $col_name)
    {
        switch ($col_name)
        {
            case _('Zone(s)'):
                $zw = DB_DataObject::Factory('zone_workgroup');
                $zw->workgroup = $row_data['id'];
                $res = $zw->find();
                $ary = array();

                switch($res) {
                
                case 1:
                    $zw->fetch();
                    $zn = new Zone($zw->zone);
                    $obj = $zn->name;
                    break;

                case 0:
                    $obj = _("No Zones");
                    break;

                default:
                    while($zw->fetch()) {
                        $zn = new Zone($zw->zone);
                        $zn->find(1);
                        $ary[$zn->name] = $zn->id;
                    }
                    $obj = form_select("zones", $ary, $_SESSION['zone']);
                }
                
                break;
            case _('Action'):
                $obj = container();
                $obj = Module::apply_filter('action_module', $obj, $row_data, 'workgroup');
                break;
            case _('Name'):
                $obj = container(html_a($_SERVER["SCRIPT_NAME"]."?action=show&amp;id=".$row_data['id'], $row_data['name']));
                break;
            default:
                $obj = DefaultGUIDataList::build_column_item($row_data, $col_name);
        }

        return $obj;
    }

//}}}
//{{{   actionbar_cell()

    /**
     *  This method is what sets the information display at the bottom of the table.
     *  
     *  @return Container   A span that has strings for displaying the page numbers
     */
    function actionbar_cell()
    {
        $current = $this->get_current_page();
        $pages = $this->get_num_pages();
        return html_span('', "You are on page $current of $pages.");
    }
//}}}

}
 
?>
