<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: HostBulkDeleteConfirm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  HostBulkDeleteConfirm - this file contains the {@link HostBulkDeleteConfirm}
 *                          class.
 *
 *  @author $Author:$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

class HostBulkDeleteConfirm extends MaintainForm
{

    var $errors = array();

//{{{   form()

    /**
     *  This method lays the form out for display.
     *
     *  @return DIVTag  $div    Div that contains the form
     */
    function form()
    {
        $div = html_div("form");
        $cont = container();
        $cont->add(_("You are going to delete the following hosts from this zone:"),html_br());

        if(!isset($_REQUEST['hostlist']))
            $cont->add(_("No hosts were selected for deletion."));
        else
            foreach($_REQUEST['hostlist'] as $hostid) {
                $host = new Host($hostid);
                $cont->add($host->getHostname() . ' ' . $host->getIp(), html_br());
            }
        $cont->add(html_br());
        $cont->add(_("Are you sure?"));
        $cont->add(html_br(),$this->add_action(_("Confirm")),$this->add_action(_("Cancel")));
        $cont->add($this->element_form("action"));
        $cont->add($this->element_form("hostlist"));
        $div->add($cont);

        return $div;
    }

//}}}
//{{{   form_action

    /**
     *  This method defines the behavior for the form based on the button pressed
     *
     *  @return boolean     true if action was successful
     */
    function form_action()
    {
        global $user;
       
        $res = true;
       
        switch(strtolower($this->get_action()))
        {
            case 'confirm':
                if(!isset($_REQUEST['hostlist']))
                    break;
                $hosts = unserialize(stripslashes($_REQUEST['hostlist']));
                foreach($hosts as $hostid) {
                    
                    $host = new Host($hostid);
                    $host->query("BEGIN");
                    $name = $host->name;
                    
                    if(!$user->is_zone_admin($host->zone)) {
                        $host->query("ROLLBACK");
                        $errors[$host->id] = _("Insufficient Permissions to Delete Host ID: ").$host->id;
                        continue;
                    }
                    
                    $success = $host->delete();
                    
                    if($success === false){
                        $host->query("ROLLBACK");
                        $errors[$host->id] = _("Delete failed for host ID: ").$host->id; 
                    }
                    
                    else
                        $host->query("COMMIT");
                        $host->write_history(_("Deleted"), ACTION_DELETE, $user->username, $host->zone);
                }
                
                if(!empty($errors)) {
                    foreach($errors as $hostid=>$error)
                        $this->add_error("Host $hostid", $error);
                    $res = false;
                }
                
                break;
               
            case 'cancel':
                header("Location: host.php");
                break;
            default:
                die_hard(_("Invalid form action"));
                break;
        }
        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method displays a message informing the user that the delete was
     *  successful.
     *
     *  @return DIVTag  $div    The div that contains the message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a("index.php", "[Return to Home]");
        $hoslink = html_a("host.php", "[Return to Host List]");
        $div->add(container("Hosts deleted successfully!",html_br()));
        $div->add(container($indlink, $hoslink));
        return $div;
    }

//}}}
//{{{   form_init_elements()

    /**
     *  This method inits the elements that are able to be included in the form.
     */
    function form_init_elements()
    {
        $this->add_element(new FEHidden("action","Bulk Host Delete"));
        $this->add_element(new FEHidden("hostlist",serialize($_REQUEST['hostlist'])));
    }

//}}}
 
}

?>
