<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: IPBlockCreateForm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  IPBlockCreateForm.php - this file contains the {@link IPBlockCreateForm} class
 *
 *  @author $Author$
 *  @pacakge    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This class is the form used to create an IPBlock
 *
 *  @package    htdocs 
 *  @subpackage forms
 */
 class IPBlockCreateForm extends MaintainForm
 {

//{{{   vars

    /**
     *  This array maps form labels to DBDO vars and vice versa
     */
    var $map = array("IP_Block_Name"=>"name",
                    "Start_Address"=>"start",
                    "End_Address"=>"end",
                    "Enabled"=>"enabled");

//}}}

//{{{   form_init_elements()

    /** 
     *  This method initializes the elements and adds them to the form object
     */
    function form_init_elements()
    {
        $name   = new FEText(_("IP Block Name"), true);
        $start  = new FEText(_("Start Address"),true);
        $end    = new FEText(_("End Address"), true);
        $enable = new FECheckBox(_("Enabled"));

        //add them in to the form object
        $this->add_elements($name, $start, $end, $enable);
    }

//}}}
//{{{   form_backend_validation()

    /**
     *  This method does validation on the form values before any other action
     *  is taken on them.
     *
     *  @return Boolean     True if the data is valid
     */
    function form_backend_validation()
    {
        $res = true;
        $vals = $this->get_all_element_values();
    
        $ipblock = new IPBlock($_REQUEST['id']);
        
        $ipblock->setAll();
        $ipblock->setFrom($this->remap($vals,DBDO));

        $ipblock->enabled = ($vals[_('Enabled')] == 1 ? 1 : 0);

        $valid = $ipblock->validate();
   
        //If it's not exactly valid
        if($valid !== true) {
            //It isn't valid so set the result
            $res = false;
            
            //get the error array and remap it to the form
            $errors = $this->remap($valid,FORM);
            
            //iterate through the returned array
            foreach($errors as $label=>$error) {
                //If this element wasn't valid
                if($error !== true)
                    //report it as an error
                    $this->add_error($label,$error);
            }
        }

        return $res; //return result
    }

//}}}
//{{{   form_action()

    /**
     *  This method performs actions on the form values after validation has 
     *  successfully completed.
     *
     *  @return Boolean     True of action was successful
     */
    function form_action()
    {
        global $user;
        $res = true;
   
        switch(strtolower($this->get_action())) {

        case 'submit':
            $dbdo = new IPBlock();
            $dbdo->query("BEGIN"); //Start the transaction James...
            $vals = $this->get_all_element_values();
            $dbdo->setFrom($this->remap($vals,DBDO));

            //Checkbox is null if not selected, but null isn't valid in the DB
            $dbdo->enabled = ($vals[_("Enabled")] == 1 ? 1 : 0);

            if(!$dbdo->insert()) {
                $dbdo->query("ROLLBACK"); //Oh Crap... go back 
                $res = false;
                $this->add_error(_("ERROR"), _("Could not insert IP Block in the database"));
            } else {
                $dbdo->query("COMMIT"); //yay, all is well and db updates
                $dbdo->write_history(_("Created new IPBlock"), ACTION_CREATE, 
                                    $user->username, $_SESSION['zone']);
            }
            break;

        default:
            die_hard(_("Invalid form action"));

        }

        return $res;
    }

//}}}
//{{{   form_success()

    /** 
     *  This method displays a success message to the user if the action was
     *  successfully completed.
     *
     *  @return DIVTag  $div    Div with the message inside
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php",_("[Return to Index]"));
        $ipllink = html_a(web_root()."ip.php",_("[Return to IPBlock List]"));
        $div->add(_("IPBlock successfully created!"),html_br());
        $div->add($indlink, $ipllink);

        return $div;
    }

//}}}

}
 
?>
