<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Danny Robert <robert@osuosl.org>                            |
// |            Zack Bartel  <bartel@osuosl.org>                            |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id$

/**
 *  InstallForms.php - This file contains the forms necessary for the 
 *  installation process.
 *
 *  @author $Author:$
 *  @package    install
 *  @subpackage htdocs
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");
require_once(FORMDIR."/ZoneCreateForm.php");

/**
 * This class contains the form necessary to set
 * the initial password for the admin account
 * as part of the install process
 *
 * @package     htdocs
 * @subpackage  forms
 */
class AdminPasswordForm extends MaintainForm
{
//{{{ form_init_elements()

    function form_init_elements()
    {
        $dbdo = DB_DataObject::Factory('user');
        $dbdo->username = 'admin';
        $dbdo->find(true);
        if($dbdo->getPassword() != sha1('changeme'))
        {
            header("Location: unavailable.php");
            exit;
        }
        $newpassword = new FEPassword(_("New Password"), true);
        $confirm = new FEConfirmPassword(_("Confirm Password"), true);
        $confirm->password($newpassword);

        $this->add_elements($newpassword, $confirm);

        // also, the hidden 'state' element
        $this->add_hidden_element('state');
        
    }
//}}}
//{{{ form_init_data()
    function form_init_data()
    {
        $this->set_hidden_element_value('state',$_REQUEST['state']);
    }
//}}}
//{{{ form_success()
    function form_success()
    {
        return container(_("Admin password successfully changed."));
    }
//}}}
//{{{ form_action()
    function form_action()
    {
        switch(strtolower($this->get_action())) {
        
        case _("submit"):
            /*We got a good password now lets change the DB (fingers crossed) */
            $vals = $this->get_all_element_values();
            $newpass = $vals[_("New_Password")];
            $user = new User('admin');
            $user->query("BEGIN"); //beginning the transaction
            $user->setPassword($newpass);
            if (!$user->update())   {
                $user->query("ROLLBACK"); //Oh F$%@... can't make a user
                $this->add_error(_("ERROR"), _("Could not update database"));
            }
            $user->query("COMMIT"); //yay, admin is in the db now...
            return true;
            break;
        default:
            die_hard(_("Invalid form action"));
            break;
        }
    }

//}}}
//{{{ form_backend_validation()
    function form_backend_validation()
    {
        $result = true;

        $vals = $this->get_all_element_values();

        /* Check new password length */
        if (strlen($vals[_("New_Password")]) < PASSWORD_MIN_LEN)   {
            $this->add_error(_("ERROR"), _("Password must be at least").' '.PASSWORD_MIN_LEN.' '._("characters"));
            return false;
        }

        /* make sure the password still isn't 'changeme' */
        if (!strcasecmp($vals[_("New_Password")], 'changeme')) {
            $this->add_error(_("ERROR"), _("Password must not be 'changeme'"));

            return false;
        }

        return $result;
    }
//}}}
}

/**
 * Form necessary to create the initial zone
 *
 * @package     htdocs
 * @subpackage  forms
 */
class InitialZoneCreateForm extends ZoneCreateForm
{
//{{{ form_init_elements
    function form_init_elements()
    {
        parent::form_init_elements();
        $this->add_hidden_element('state');
    }
//}}}
//{{{ form_init_data()
    function form_init_data()
    {
        $this->set_hidden_element_value('state',$_REQUEST['state']);
    }
//}}}
//{{{ form_success()
    function form_success()
    {
        return container(_("Initial zone successfully created."));
    }
//}}}
}

/**
 * Form necessary to create the database tables in a clear database
 *
 * @package     htdocs
 * @subpackage  forms
 */
class InstallDBForm extends FormContent
{
//{{{ form_init_elements()
    function form_init_elements()
    {
        //This is a check to see if the database already exists or not. 
        //If it does, and you are seeing the install script, then there
        //is something afoot that you should not be playing with, and so
        //you are immediately DENIED
        $dbdo = DB_DataObject::Factory('update_info');
        if($dbdo->find())
        {
            header("Location: unavailable.php");
            exit;
        }
        //you are immediately DENIED
        //$dbdo = DB_DataObject::Factory('update_info');
        //if($dbdo->find())
        //{
        //    header("Location: unavailable.php");
        //    exit;
        //}
        $s = new FEHidden("state", $_REQUEST['state']);
        $this->add_element($s);

    }
//}}}
//{{{ form()
    function form()
    {
        $div = html_div();
        $div->add("Maintain has detected that there is no previous Maintain database. <br/>Maintain will now attempt to install the database. <br/><br/>Click OK to continue<br/><br/>");
        $div->add($this->add_action(_("OK")));
        $div->add($this->element_form("state"));
        return $div;
    }
//}}}
//{{{ form_action()
    function form_action()
    {
        global $conf;
        $dbh = dbh();
        /* DB exists lets add some tables */
        $script = $conf['paths']['prefix']."/install/sql/maintain.sql"; 
        $query = fread(fopen($script, "r"), filesize($script)); 

        $stmts = explode(";", $query);
        foreach ($stmts as $sql)
            if ($sql[0] != '-' && $sql[0] != '#')
                mysql_query($sql, $dbh);
        return true;
    }
//}}}
//{{{ form_backend_validation()
    function form_backend_validation()
    {
        return true;
    }
//}}}
//{{{ form_success()
    function form_success()
    {
        return container(_("Database successfully setup"));
    }
//}}}
}

/**
 * Form to handle cascading updates in a pre-existing database
 *
 *
 * @package     htdocs
 * @subpackage  forms
 */
class UpdateDBForm extends FormContent
{

//{{{ form_init_elements()
    function form_init_elements()
    {
        $s = new FEHidden("state", $_REQUEST['state']);
        $this->add_element($s);
    }
//}}}
//{{{ form()
    function form()
    {
        $div = html_div();
        $div->add(_("Maintain has detected a previous database. Maintain will now attempt to upgrade the database to version ".MAINTAIN_DB_VERSION."."));
        $div->add(html_br(1), _("If you have not backed up your current database please do so now."));
        $div->add(html_br(2), _("Please note that this process may take a while. If your update is major (e.g. if you have a lot of hosts or similar), feel free to get a coffee."));
        $div->add(html_br(2), $this->add_action("OK"));
        $div->add($this->element_form("state"));
        return $div;
    }
//}}}
//{{{ form_action()
    function form_action()
    {
        require_once(CLASSDIR.'/update.php');
        $update = new Update();
        $msg = $update->run_update();
        if($msg !== true)
        {
            $this->add_error(_("ERROR"), $msg
                ."<br>If you need help tracking down this problem, go to ".MAINTAIN_WEBSITE
                ." for community support.");
            return false;
        }
        
        return true;
    }
//}}}    
//{{{ form_success()
    function form_success()
    {
        return container(_("Successfully upgraded database"));   
    }
//}}}
}
?>
