<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: MaintainDeleteConfirm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  MaintainDeleteConfirm.php - Contains the {@link MaintainDeleteConfirm}
 *                              class
 *  @author     $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

/**
 *  This class is the delete confirm page
 *
 *  @package    htdocs
 *  @subpackege forms
 */
class MaintainDeleteConfirm extends FormContent
{

    var $type;
    var $func;

//{{{   constructor()

    /**
     *  This is the constructor for a delete confirm.  It needs to know the type
     *  of object as well as which field you want to use when asking them if they
     *  are sure they want to delete it.
     *
     *  @param  string  $type           The type of object we're deleteing
     *  @param  string  $displayField   The field we're going to use to reference it
     */
    function MaintainDeleteConfirm($type,  $displayField)
    {
        $this->type = $type;
        $this->func = "get".$displayField;
    }

//}}}
//{{{   form()
    /**
     *  This method lays the form out for display.
     *
     *  @return DIVTag  $div    Div that contains the form
     */
    function form()
    {
        if(!class_exists($this->type))
            die_hard(_("Invalid class specified!"));
            
        $obj = new $this->type($_REQUEST['id']);
        $function = $this->func;
        
        $div = html_div("delconfirm");
        $cont = container();
        $cont->add(_("You are going to delete ").$obj->$function());
        $cont->add(html_br());
        $cont->add(_("Are you sure?"));
        $cont->add(html_br(),$this->add_action(_("Confirm")),$this->add_cancel(_("Cancel")));
        $cont->add($this->element_form("action"));
        $cont->add($this->element_form("id"));
        $div->add($cont);

        return $div;
    }

//}}}
//{{{   form_action

    /**
     *  This method defines the behavior for the form based on the button pressed
     *
     *  @return boolean     true if action was successful
     */
    function form_action()
    {
        global $user;
        $res = true;

        switch(strtolower($this->get_action())){
        
        case 'confirm':
            $obj = new $this->type($_REQUEST['id']);
            $obj->query("BEGIN");
            
            if($obj->delete() === false) {
                $obj->query("ROLLBACK");
                $this->add_error(_("ERROR"), $this->type.' '._("could not be delete from DB"));
                $res = false;
            } else {
                $obj->query("COMMIT");
                $obj->write_history($this->type.' '._("Deleted"), ACTION_DELETE,
                                    $user->username, $_SESSION['zone']);
            }
            break;
            
        default:
            $this->add_error(_("ERROR"), _("Invalid form action specified"));
            $res = false;
            break;
            
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method displays a message informing the pointer that the delete was
     *  successful.
     *
     *  @return DIVTag  $div    The div that contains the message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php", _("[Return to Home]"));
        $listlink = html_a($_SERVER["SCRIPT_NAME"], _("[Return to $this->type List]"));
        $div->add(container(_("$this->type deleted successfully!"),html_br()));
        $div->add(container($indlink, $listlink));
        return $div;
    }

//}}}
//{{{   form_init_elements()

    /**
     *  This method inits the elements that are able to be included in the form.
     */
    function form_init_elements()
    {
        $this->add_element(new FEHidden("action",$_REQUEST['action']));
        $this->add_element(new FEHidden("id", $_REQEST['id']));
        $this->set_action($_SERVER["SCRIPT_NAME"]);
        $this->set_cancel_action($_SERVER["SCRIPT_NAME"]);
    }

//}}}

}

?>
