<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: RangeZoneAddForm.php 4822 2006-09-15 18:57:40Z morgabra $

require_once(FORMDIR."/MaintainForm.php");

class RangeZoneAddForm extends MaintainForm
{

/*Vars*/
//{{{   vars

    /**
     *  Maps form values to DBDO values
     */
    var $map = array('Add_Zone' => 'zone',
                    'Default_Domain' => 'default_domain');

//}}}

/*Methods*/
//{{{   form_init_elements()

    /**
     *  This method initializes the elements of the form
     */
    function form_init_elements()
    {
        $zones = new FEListBox(_("Add Zone"));
        $domains = new FEListBox(_("Default Domain"));
        $require = new FECheckBox(_("Require All Domains in Zone"));

        $zones->set_list_data($this->_zones());
        $domains->set_list_data($this->_domains());

        $this->add_elements($zones, $domains, $require);
    }

//}}}
//{{{   form_backend_validation()

    function form_backend_validation()
    {
        $vals = $this->get_all_element_values();
        $res = true;
        
        //First lets make sure that the mapping doesn't already exist
        $zr = DB_DataObject::Factory('zone_range');
        $zr->zone = $vals['Add_Zone'];
        $zr->range = $_REQUEST['id'];

        if($zr->find()) {
            $this->add_error(_("Add Zone"), _("Entry Already Exists!"));
            $res = false;
        }

        //Check to make sure the Domain is actually allowed to be in that zone
        $obj = DB_DataObject::Factory('zone_domain');
        $obj->zone = $vals['Add_Zone'];
        $obj->domain = $vals['Default_Domain'];

        if(!$obj->find()) {
            $this->add_error(_('Default Domain'), 
                            _('Specified domain is not in specified zone'));
            $res = false;
        }

        //If they want, make sure all the domains in the range match the zone
        if($vals['Require_All_Domains_in_Zone']) {
            $zn = new Zone($vals['Add_Zone']);
            $range = new Range($_REQUEST['id']);
            $domains = $range->get_represented_domains();

            $obj = DB_DataObject::Factory('zone_domain');
            $obj->zone = $vals['Add_Zone'];
            foreach($domains as $domain)
                $obj->whereAdd("domain = $domain");
            
            $count = $obj->find();

            if($count != count($domains)) {
                $this->add_error(_('Require All Domains in Zone'),
                                _("Range Domains don't match".' '.$zn->name));
                $res = false;
            }
        }

        return $res;
        
    }

//}}}
//{{{   form_action()
    
    /**
     *  This method is what actually processes the form request and makes the
     *  appriopriate database queries.
     *
     *  @return Boolean True if action is successful
     */
    function form_action() 
    {
        global $user;
        $res = true;
        
        switch(strtolower($this->get_action())) {
        
        case 'submit':
            $vals = $this->get_all_element_values();
            $obj = DB_DataObject::Factory('zone_range');
            $obj->query("BEGIN");
            $obj->zone = $vals['Add_Zone'];
            $obj->range = $_REQUEST['id'];
            $obj->default_domain = $vals['Default_Domain'];
            $obj->enabled = 1;

            if(!$obj->insert()) {
                $obj->query("ROLLBACK");
                $this->add_error(_("ERROR"), _("Could not make database entry!"));
                $res = false;
            } else {
                $obj->query("COMMIT");
                $range = new Range($_REQUEST['id']);
                $range->write_history(_("Added Zone Range Mapping"), ACTION_CREATE,
                                    $user->username, $vals['Add_Zone']);
            }
            
            break;

        default:
            $this->add_error(_("ERROR"), _("Unknown form action"));
            break;
            
        }
        
        return $res;
    }

//}}}
//{{{   form_hidden()

    /**
     *  This method adds the hidden elements to the form to retain some necessary
     *  information such as the action and ID for the object we're working with.
     *
     *  @return Container   Container with hidden elements inside
     */
    function form_hidden() 
    {
        $action = new FEHidden("action","edit");
        $objid = new FEHidden("id",$_REQUEST['id']);

        $this->add_elements($objid, $action);

        return container($this->element_form("id"), $this->element_form("action"));
    }

//}}}

/*Helper Methods*/
//{{{   _zones()

    /**
     *  Helper method to generate an array to fill up the Zone List Box
     *
     *  @return Array   $zoneary    Array of zones indexed by name
     */
    function _zones()
    {
        $zoneary = array();

        $zn = DB_DataObject::Factory('zone');
        $zn->orderBy('name ASC');
        $zn->find();

        while($zn->fetch()) {
            $zoneary[$zn->name] = $zn->id;
        }
        
        return $zoneary;
    }

//}}}
//{{{   _domains()

    function _domains()
    {
        $obj = DB_DataObject::Factory('domain');
        $obj->orderBy("name ASC");
        $obj->find();
        while($obj->fetch())
            $array[$obj->name] = $obj->id;

        return $array;
    }

//}}}

}

?>
