<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// +------------------------------------------------------------------------+
// $Id: VlanCreateForm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  VlanCreateForm.php - contains the {@link VlanCreateForm} class
 *
 *  @author $Author:$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

class VlanCreateForm extends MaintainForm
{


    var $map = array("VLAN_Name"=>"name",
                    "VLAN_ID"=>"vlan_id");
                    
//{{{   form_init_elements()
    
    /**
     *  This is the method that initializes all the form elements and labels
     *  to be used later on when we actually render everything to the screen.
     */
    function form_init_elements()
    {
        $name = new FEText(_("VLAN Name"),true);
        $id = new FEText(_("VLAN ID"),true);

        $this->add_elements($name, $id);
        $this->set_action($_SERVER['SCRIPT_NAME']);
    }

//}}}
//{{{   form_backend_validation()

    /**
     *  This method makes sure that the form values are all valid before being
     *  processed by the form_action method and entered into the database.
     *
     *  @return Boolean $res    True if form values are valid
     */
    function form_backend_validation()
    {
        $res = true;
        
        $dbdobj = new Vlan($_REQUEST['id']);
        $dbdobj->setFrom($this->remap($this->get_all_element_values(),DBDO));

        $valid = $dbdobj->validate();

        if($valid !== true) {
            $res = false;
            $errors = $this->remap($valid, FORM);
            
            foreach($errors as $label=>$error) {
                if($error !== true)
                    $this->add_error($label, $error);
            }
        }

        return $res;        
    }

//}}}
//{{{   form_action()

    /**
     *  This method processes the information after validation has determined it
     *  is valid.
     *
     *  @return Boolean $res    True if action was successful
     */
    function form_action()
    {
        $res = true;
    
        $vlan = new Vlan();
        $vlan->query("BEGIN");
        $vlan->setfrom($this->remap($this->get_all_element_values(),DBDO));

        if(!$vlan->insert()) {
            $vlan->query("ROLLBACK");
            $res = false;
            $this->add_error(_("ERROR"), 
                            _("The VLAN could not be inserted in the database!"));
        } else {
            $vlan->query("COMMIT");
            $vlan->write_history(_("Created Vlan"), ACTION_CREATE, $user->username);
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method displays a message informing that the vlan was successfully
     *  created.
     *
     *  @return DIVTag  $div    The div that contains the message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a("index.php", _("[Return to Home]"));
        $wglink = html_a("vlan.php", _("[Return to VLAN List]"));
        $div->add(container(_("VLAN created successfully!"),html_br()));
        $div->add(container($indlink, $wglink));
        return $div;
    }   

//}}}

}

?>
