<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: VlanEditForm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  VlanEditForm.php - contains the {@link VlanEditForm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/VlanCreateForm.php");

/**
 *  This class is a edit form for Vlans
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class VlanEditForm extends VlanCreateForm 
{

//{{{   form_init_data()

    /**
     *  Fill in the existing values of the Vlan
     */
    function form_init_data()
    {  
        $vlan = new Vlan($_REQUEST['id']);
        $formary = $this->remap($vlan->toArray(), FORM);
        
        foreach($formary as $label=>$val) 
            $this->set_element_value($label, $val);
    }

//}}}
//{{{   form_action()

    /**
     *  Update the database entry for the Vlan using form values
     *
     *  @return boolean True if action was successful
     */
    function form_action() 
    {
        global $user;
        $res = true;

        switch(strtolower($this->get_action())) {

        case 'submit':
            $vlan = new Vlan($_REQUEST['id']);
            $vlan->query("BEGIN");
            $array = $this->get_all_element_values();

            $vlan->setFrom($this->remap($array, DBDO));

            if($vlan->update() === false) {
                $vlan->query("ROLLBACK");
                $res = false;
                $this->add_error(_("ERROR"), _("Could not modify Vlan DB Entry!"));
            } else {
                $vlan->query("COMMIT");
                $vlan->write_history(_("VLAN Modified"), ACTION_MODIFY, 
                                    $user->username, $_SESSION['zone']);
            }
            break;

        default:
            $this->add_error(_("ERROR"), _("Invalid form action!"));
            break;
        
        }

        return $res;

    }
//}}}
//{{{   form_success()

    /**
     *  This method displays a success message to the user letting them know it worked.
     *
     *  @return DIVTag  $div    Div that contains a success message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $div->add(_("VLAN Successfully Modified"));
        return $div;
    }

//}}}
//{{{   form_hidden()

    function form_hidden()
    {
        $cont = container();
        $act = new FEHidden("action","edit");
        $idnum = new FEHidden("id",$_REQUEST['id']);

        $this->add_elements($act, $idnum);
        
        $cont->add($this->element_form(_('action')), $this->element_form(_('id')));
        return $cont;
    }

//}}}

}

?>
