<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: ZoneDomainForm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  ZoneDomainForm.php - contains the {@link ZoneDomainForm} class
 *
 *  @author $Author$
 *  @filesource
 *  @package    htdocs
 *  @subpackage forms
 */

require_once("MaintainForm.php");

/**
 *  This class is a form that is used to add or remove a domain to/from a zone.
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class ZoneDomainForm extends MaintainForm
{

//{{{   form_init_elements()

    /**
     *  This method is where we initialize all of the elements that are part of
     *  the form.
     */
    function form_init_elements()
    {
        $current = array();
        $potential = array();
        
        $add = new FEListBox(_("Add Domain"), false);
        $rem = new FEListBox(_("Remove Domain"), false);

        $domobj = DB_DataObject::Factory('domain');
        $domobj->orderBy('name ASC');
        $domobj->find();

        while($domobj->fetch())
            $potential[$domobj->name] = $domobj->id;

        $domobj->free();
        
        $add->set_list_data($potential);

        $zd = DB_DataObject::Factory('domain');
        $zob = DB_DataObject::Factory('zone_domain');
        $zob->zone = $_SESSION['zone'];
        $zd->joinAdd($zob);
        $zd->find();
        
        while($zd->fetch())
            $current[$zd->name] = $zd->id;

        $zd->free();
        $zob->free();
    
        $rem->set_list_data($current);
        
        $addbut = new FESubmitButton(_("Add"), _("Add"));
        $rembut = new FESubmitButton(_("Remove"), _("Remove"));

        $this->add_elements($add, $rem, $addbut, $rembut);
    }

//}}}
//{{{   form()

    /**
     *  This method is what generates the form for displaying to the screen.
     *
     *  @return DIVTag  $div    Div with the form contained inside of it.
     */
    function form()
    {
        $div = html_div("form");
        $table = html_table();

        $class = array(0=>"even",
                        1=>"odd");

        $temp = 1;

        //Add the form elements
        $tr = html_tr($class[++$temp%2]);
        $tr->add($this->element_label(_("Add Domain")), 
                $this->element_form(_("Add Domain")), 
                $this->add_action(_("Add")));
        $table->add($tr);


        $tr = html_tr($class[++$temp%2]);
        $tr->add($this->element_label(_("Remove Domain")), 
                $this->element_form(_("Remove Domain")), 
                $this->add_action(_("Remove")));
        $table->add($tr);

        $cont = container();
        $act = new FEHidden("action", "edit");
        $idnum = new FEHidden("id",$_REQUEST['id']);
        $this->add_elements($act, $idnum);
        
        $cont->add($this->element_form("action"),$this->element_form("id"));

        $div->add($table);
        $div->add($cont);

        return $div;
    }

//}}}
//{{{   form_action()

    /**
     *  This method is used to take the appropriate action given the form input.
     *
     *  @return Boolean True If successful
     */
    function form_action()
    {
        global $user;
        $res = true;

        switch(strtolower($this->get_action())) {

        case 'add':
            $zdobj = DB_DataObject::factory('zone_domain');
            $zdobj->query("BEGIN");
            $zdobj->zone = $_SESSION['zone'];
            $zdobj->domain = $this->get_element_value(_("Add Domain"));

            if(!$zdobj->insert()) {
                $zdobj->query("ROLLBACK");
                $res = false;
                $this->add_error(_("ERROR"), _("Failed to add item to database"));
            } else {
                $zdobj->query("COMMIT");
                $zn = new Zone($_REQUEST['id']);
                $zn->write_history(_("Added Zone-Domain mapping"), ACTION_CREATE,
                                        $user->username, $_REQUEST['id']);
            }
            
            break;
            
        case 'remove':
            $zdobj = DB_DataObject::factory('zone_domain');
            $zdobj->id = $this->get_element_value(_("Remove Domain"));
            $zdobj->find();

            if(!$zdobj->delete()) {
                $res = false;
                $this->add_error(_("ERROR"), _("Failed to remove item from database"));
            } else {
                $zn = new Zone($_REQUEST['id']);
                $zn->write_history(_("Remove Zone-Domain mapping"), ACTION_DELETE,
                                        $user->username, $zn->id);
            }

            break;
        }
        
        return $res;
    }

//}}}
//{{{ form_backend_validation()
    function form_backend_validation()
    {
        $result = true;
        $domain = $this->get_element_value(_("Add Domain"));
        $zd = DB_DataObject::Factory('zone_domain');
        $zd->domain = $domain;
        $zd->zone = $_SESSION['zone'];
        if ($zd->find())    {
            $this->add_error("Add Domain", "Specified domain already belongs to this zone");
            return false;
        }
        return true;
    }
//}}}
//{{{ form_success()

    /**
     *  This method is executed upon a successful form action, in this case it
     *  takes them back to the edit page so they may continue.
     */
    function form_success()
    {
        header("Location: ".web_root()."zone.php?action=".$_REQUEST['action'].
                                                "&id=".$_REQUEST['id']);
    }

//}}}

}

?>
