<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: ZonePHostsConfirm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  ZonePHostsConfirm.php - contains the {@link ZonePHostsConfirm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This is a confirm page for if the user decides to purge the zone of hosts.
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class ZonePHostsConfirm extends MaintainForm
{

//{{{   form_init_elements()

    /**
     *  This method is where all the form elements get intialized before use
     */
    function form_init_elements()
    {
        $hidden = new FEHidden("action",$_REQUEST['action']);
        $this->add_element($hidden);
    }

//}}}
//{{{   form()

    /**
     *  This method lays out the form to the user and also adds the the actions
     *  to the page.
     *
     *  @return DIVTag  $div    Div with the form inside
     */
    function form()
    {
        $zn = new Zone($_SESSION['zone']);
        $this->set_cancel_action($_SERVER["SCRIPT_NAME"]);
        
        $div = html_div("form");
        $div->add(_("WARNING!  You are about to purge zone number").' '.$zn->id.
                    _(', ').$zn->name.' '
                    ._("of all hosts!  Are you sure you want to do this?"),
                    html_br());
        $div->add($this->add_action(_("Confirm")),$this->add_cancel());
        $div->add($this->element_form(_("action")));


        return $div;
    }

//}}}
//{{{   form_action()

    /**
     *  This is the method that performs the desired action.  In this case it
     *  deletes all the hosts from the zone if the action was confirmed.
     *
     *  @return Boolean     True if the purge was successful
     */
    function form_action()
    {
        global $user;

        $res = true;
    
        switch(strtolower($this->get_action())) {

            case 'confirm':
                $host = new host();
                $host->query("BEGIN");
                $host->zone = $_SESSION['zone'];
                $host->find();
                
                while($host->fetch()) {
                    if(!$host->delete()) {
                        $host->query("ROLLBACK");
                        $this->add_error("ERROR", _("Host number").' '.$host->id.
                                        ", ".$host->name.' '._("failed to delete!"));
                        $res = false;
                    } else {
                        $host->query("COMMIT");
                        $host->write_history(_("Host Deleted"), ACTION_DELETE, 
                                            $user->username, $_SESSION['zone']);
                    }
                }
                
                break;
                
            default:
                die_hard(_("Invalid form action"));
                break;
        }
	
        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method displays a message indication to the user that their action
     *  was complete successfully.
     *
     *  @return DIVTag  $div    Div that contains the success message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php", _("[Return to Index]"));
        $hoslink = html_a(web_root()."host.php",_("[Go to Host List]"));
        $msg = _("Zone number").' '.$_SESSION['zone'].' '._("was successfully purged of hosts!");
        $div->add($msg,html_br(),$indlink,$hostlink);

        return $div;
    }

//}}}

}

?>
