<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: ZonePurgeConfirm.php 4822 2006-09-15 18:57:40Z morgabra $

/**
 *  ZonePurgeConfirm.php - This file contains the {@link ZonePurgeConfirm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

/**
 *  This class is the confirm page to completely purge a zone.
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class ZonePurgeConfirm extends FormContent
{

//{{{   form_init_elements()

    /**
     *  This method is responsible for initializing all the form elements that
     *  are going to be used.
     */
    function form_init_elements()
    {
        $hidden = new FEHidden("action", $_REQUEST['action']);
        $this->add_element($hidden);
    }

//}}}
//{{{   form()

    /**
     *  This method lays the form out for the user and adds the actions to the object.
     *
     *  @return DIVTag  $div    A div that contains the form
     */
    function form()
    {
        $zn = new Zone($_SESSION['zone']);
        $this->set_cancel_action(web_root()."index.php");
    
        $div = html_div("form");
        $div->add(_("You are about to purge zone number").' '.$zn->id.', '.
                    $zn->name.', '._("are you sure you want to do this?"),html_br());
        $div->add($this->add_action(_("Confirm")), $this->add_cancel());

        $div->add($this->element_form(_("action")));

        return $div;
    }
    
//}}}
//{{{   form_action()

    /**
     *  This method performs the necessary action on the given data.  In this case
     *  it purges the zone.
     *
     *  @return Boolean     True if action was successful
     */
    function form_action()
    {
        global $user;
        $res = true;

        switch(strtolower($this->get_action())) {

        case _('confirm'):
            $zn = new Zone($_SESSION['zone']);
            $zn->query("BEGIN");
            if($zn->purge_zone() === false) {
                $zn->query("ROLLBACK");
                $this->add_error(_("ERROR"), _("Zone is not purgeable!"));
                $res = false;
            } else {
                $zn->query("COMMIT");
                $zn->write_history(_("Zone purged"), ACTION_DELETE, 
                                    $user->username, $_SESSION['zone']);
            }
            break;

        default:
            die_hard(_("Invalid form action"));
            break;
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method displays a message informing the user that the purge was successful
     *
     *  @return DIVTag  $div    A div tag with the message ins
     */
    function form_success()
    {

        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php",_("[Return to Index]"));
        $div->add(_("Zone purge successful!"),html_br());
        $div->add($indlink);
        
        return $div;

    }

//}}}

}

?>
